==> physx-jni-0.4.1-sources.jar: physx/physics/PxRigidBody.java <==
package physx.physics;

import physx.common.PxTransform;
import physx.common.PxVec3;

public class PxRigidBody extends PxRigidActor {

    protected PxRigidBody() { }

    public static PxRigidBody wrapPointer(long address) {
        return address != 0L ? new PxRigidBody(address) : null;
    }
    
    protected PxRigidBody(long address) {
        super(address);
    }

    // Functions

    /**
     * @param pose WebIDL type: {@link PxTransform} [Const, Ref]
     */
    public void setCMassLocalPose(PxTransform pose) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setCMassLocalPose(address, pose.getAddress());
    }
    private static native void _setCMassLocalPose(long address, long pose);

    /**
     * @return WebIDL type: {@link PxTransform} [Value]
     */
    public PxTransform getCMassLocalPose() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxTransform.wrapPointer(_getCMassLocalPose(address));
    }
    private static native long _getCMassLocalPose(long address);

    /**
     * @param mass WebIDL type: float
     */
    public void setMass(float mass) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMass(address, mass);
    }
    private static native void _setMass(long address, float mass);

    /**
     * @return WebIDL type: float
     */
    public float getMass() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMass(address);
    }
    private static native float _getMass(long address);

    /**
     * @return WebIDL type: float
     */
    public float getInvMass() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getInvMass(address);
    }
    private static native float _getInvMass(long address);

    /**
     * @param m WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setMassSpaceInertiaTensor(PxVec3 m) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMassSpaceInertiaTensor(address, m.getAddress());
    }
    private static native void _setMassSpaceInertiaTensor(long address, long m);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMassSpaceInertiaTensor() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getMassSpaceInertiaTensor(address));
    }
    private static native long _getMassSpaceInertiaTensor(long address);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMassSpaceInvInertiaTensor() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getMassSpaceInvInertiaTensor(address));
    }
    private static native long _getMassSpaceInvInertiaTensor(long address);

    /**
     * @param linDamp WebIDL type: float
     */
    public void setLinearDamping(float linDamp) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setLinearDamping(address, linDamp);
    }
    private static native void _setLinearDamping(long address, float linDamp);

    /**
     * @return WebIDL type: float
     */
    public float getLinearDamping() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getLinearDamping(address);
    }
    private static native float _getLinearDamping(long address);

    /**
     * @param angDamp WebIDL type: float
     */
    public void setAngularDamping(float angDamp) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setAngularDamping(address, angDamp);
    }
    private static native void _setAngularDamping(long address, float angDamp);

    /**
     * @return WebIDL type: float
     */
    public float getAngularDamping() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getAngularDamping(address);
    }
    private static native float _getAngularDamping(long address);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getLinearVelocity() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getLinearVelocity(address));
    }
    private static native long _getLinearVelocity(long address);

    /**
     * @param linVel WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setLinearVelocity(PxVec3 linVel) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setLinearVelocity(address, linVel.getAddress());
    }
    private static native void _setLinearVelocity(long address, long linVel);

    /**
     * @param linVel   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param autowake WebIDL type: boolean
     */
    public void setLinearVelocity(PxVec3 linVel, boolean autowake) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setLinearVelocity(address, linVel.getAddress(), autowake);
    }
    private static native void _setLinearVelocity(long address, long linVel, boolean autowake);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getAngularVelocity() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getAngularVelocity(address));
    }
    private static native long _getAngularVelocity(long address);

    /**
     * @param angVel WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setAngularVelocity(PxVec3 angVel) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setAngularVelocity(address, angVel.getAddress());
    }
    private static native void _setAngularVelocity(long address, long angVel);

    /**
     * @param angVel   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param autowake WebIDL type: boolean
     */
    public void setAngularVelocity(PxVec3 angVel, boolean autowake) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setAngularVelocity(address, angVel.getAddress(), autowake);
    }
    private static native void _setAngularVelocity(long address, long angVel, boolean autowake);

    /**
     * @return WebIDL type: float
     */
    public float getMaxLinearVelocity() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMaxLinearVelocity(address);
    }
    private static native float _getMaxLinearVelocity(long address);

    /**
     * @param maxLinVel WebIDL type: float
     */
    public void setMaxLinearVelocity(float maxLinVel) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMaxLinearVelocity(address, maxLinVel);
    }
    private static native void _setMaxLinearVelocity(long address, float maxLinVel);

    /**
     * @return WebIDL type: float
     */
    public float getMaxAngularVelocity() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMaxAngularVelocity(address);
    }
    private static native float _getMaxAngularVelocity(long address);

    /**
     * @param maxAngVel WebIDL type: float
     */
    public void setMaxAngularVelocity(float maxAngVel) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMaxAngularVelocity(address, maxAngVel);
    }
    private static native void _setMaxAngularVelocity(long address, float maxAngVel);

    /**
     * @param force WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void addForce(PxVec3 force) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addForce(address, force.getAddress());
    }
    private static native void _addForce(long address, long force);

    /**
     * @param force WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode  WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void addForce(PxVec3 force, int mode) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addForce(address, force.getAddress(), mode);
    }
    private static native void _addForce(long address, long force, int mode);

    /**
     * @param force    WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode     WebIDL type: {@link PxForceModeEnum} [enum]
     * @param autowake WebIDL type: boolean
     */
    public void addForce(PxVec3 force, int mode, boolean autowake) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addForce(address, force.getAddress(), mode, autowake);
    }
    private static native void _addForce(long address, long force, int mode, boolean autowake);

    /**
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void addTorque(PxVec3 torque) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addTorque(address, torque.getAddress());
    }
    private static native void _addTorque(long address, long torque);

    /**
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode   WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void addTorque(PxVec3 torque, int mode) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addTorque(address, torque.getAddress(), mode);
    }
    private static native void _addTorque(long address, long torque, int mode);

    /**
     * @param torque   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode     WebIDL type: {@link PxForceModeEnum} [enum]
     * @param autowake WebIDL type: boolean
     */
    public void addTorque(PxVec3 torque, int mode, boolean autowake) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _addTorque(address, torque.getAddress(), mode, autowake);
    }
    private static native void _addTorque(long address, long torque, int mode, boolean autowake);

    /**
     * @param mode WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void clearForce(int mode) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _clearForce(address, mode);
    }
    private static native void _clearForce(long address, int mode);

    /**
     * @param mode WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void clearTorque(int mode) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _clearTorque(address, mode);
    }
    private static native void _clearTorque(long address, int mode);

    /**
     * @param force  WebIDL type: {@link PxVec3} [Const, Ref]
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setForceAndTorque(PxVec3 force, PxVec3 torque) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setForceAndTorque(address, force.getAddress(), torque.getAddress());
    }
    private static native void _setForceAndTorque(long address, long force, long torque);

    /**
     * @param force  WebIDL type: {@link PxVec3} [Const, Ref]
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode   WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void setForceAndTorque(PxVec3 force, PxVec3 torque, int mode) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setForceAndTorque(address, force.getAddress(), torque.getAddress(), mode);
    }
    private static native void _setForceAndTorque(long address, long force, long torque, int mode);

    /**
     * @param flag  WebIDL type: {@link PxRigidBodyFlagEnum} [enum]
     * @param value WebIDL type: boolean
     */
    public void setRigidBodyFlag(int flag, boolean value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setRigidBodyFlag(address, flag, value);
    }
    private static native void _setRigidBodyFlag(long address, int flag, boolean value);

    /**
     * @param inFlags WebIDL type: {@link PxRigidBodyFlags} [Ref]
     */
    public void setRigidBodyFlags(PxRigidBodyFlags inFlags) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setRigidBodyFlags(address, inFlags.getAddress());
    }
    private static native void _setRigidBodyFlags(long address, long inFlags);

    /**
     * @return WebIDL type: {@link PxRigidBodyFlags} [Value]
     */
    public PxRigidBodyFlags getRigidBodyFlags() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRigidBodyFlags.wrapPointer(_getRigidBodyFlags(address));
    }
    private static native long _getRigidBodyFlags(long address);

    /**
     * @param advanceCoefficient WebIDL type: float
     */
    public void setMinCCDAdvanceCoefficient(float advanceCoefficient) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMinCCDAdvanceCoefficient(address, advanceCoefficient);
    }
    private static native void _setMinCCDAdvanceCoefficient(long address, float advanceCoefficient);

    /**
     * @return WebIDL type: float
     */
    public float getMinCCDAdvanceCoefficient() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMinCCDAdvanceCoefficient(address);
    }
    private static native float _getMinCCDAdvanceCoefficient(long address);

    /**
     * @param biasClamp WebIDL type: float
     */
    public void setMaxDepenetrationVelocity(float biasClamp) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMaxDepenetrationVelocity(address, biasClamp);
    }
    private static native void _setMaxDepenetrationVelocity(long address, float biasClamp);

    /**
     * @return WebIDL type: float
     */
    public float getMaxDepenetrationVelocity() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMaxDepenetrationVelocity(address);
    }
    private static native float _getMaxDepenetrationVelocity(long address);

    /**
     * @param maxImpulse WebIDL type: float
     */
    public void setMaxContactImpulse(float maxImpulse) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMaxContactImpulse(address, maxImpulse);
    }
    private static native void _setMaxContactImpulse(long address, float maxImpulse);

    /**
     * @return WebIDL type: float
     */
    public float getMaxContactImpulse() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMaxContactImpulse(address);
    }
    private static native float _getMaxContactImpulse(long address);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getInternalIslandNodeIndex() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getInternalIslandNodeIndex(address);
    }
    private static native int _getInternalIslandNodeIndex(long address);

}

==> physx-jni-0.4.16-sources.jar: physx/physics/PxRigidBody.java <==
package physx.physics;

import physx.common.PxTransform;
import physx.common.PxVec3;

public class PxRigidBody extends PxRigidActor {

    protected PxRigidBody() { }

    public static PxRigidBody wrapPointer(long address) {
        return address != 0L ? new PxRigidBody(address) : null;
    }
    
    protected PxRigidBody(long address) {
        super(address);
    }

    // Functions

    /**
     * @param pose WebIDL type: {@link PxTransform} [Const, Ref]
     */
    public void setCMassLocalPose(PxTransform pose) {
        checkNotNull();
        _setCMassLocalPose(address, pose.getAddress());
    }
    private static native void _setCMassLocalPose(long address, long pose);

    /**
     * @return WebIDL type: {@link PxTransform} [Value]
     */
    public PxTransform getCMassLocalPose() {
        checkNotNull();
        return PxTransform.wrapPointer(_getCMassLocalPose(address));
    }
    private static native long _getCMassLocalPose(long address);

    /**
     * @param mass WebIDL type: float
     */
    public void setMass(float mass) {
        checkNotNull();
        _setMass(address, mass);
    }
    private static native void _setMass(long address, float mass);

    /**
     * @return WebIDL type: float
     */
    public float getMass() {
        checkNotNull();
        return _getMass(address);
    }
    private static native float _getMass(long address);

    /**
     * @return WebIDL type: float
     */
    public float getInvMass() {
        checkNotNull();
        return _getInvMass(address);
    }
    private static native float _getInvMass(long address);

    /**
     * @param m WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setMassSpaceInertiaTensor(PxVec3 m) {
        checkNotNull();
        _setMassSpaceInertiaTensor(address, m.getAddress());
    }
    private static native void _setMassSpaceInertiaTensor(long address, long m);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMassSpaceInertiaTensor() {
        checkNotNull();
        return PxVec3.wrapPointer(_getMassSpaceInertiaTensor(address));
    }
    private static native long _getMassSpaceInertiaTensor(long address);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMassSpaceInvInertiaTensor() {
        checkNotNull();
        return PxVec3.wrapPointer(_getMassSpaceInvInertiaTensor(address));
    }
    private static native long _getMassSpaceInvInertiaTensor(long address);

    /**
     * @param linDamp WebIDL type: float
     */
    public void setLinearDamping(float linDamp) {
        checkNotNull();
        _setLinearDamping(address, linDamp);
    }
    private static native void _setLinearDamping(long address, float linDamp);

    /**
     * @return WebIDL type: float
     */
    public float getLinearDamping() {
        checkNotNull();
        return _getLinearDamping(address);
    }
    private static native float _getLinearDamping(long address);

    /**
     * @param angDamp WebIDL type: float
     */
    public void setAngularDamping(float angDamp) {
        checkNotNull();
        _setAngularDamping(address, angDamp);
    }
    private static native void _setAngularDamping(long address, float angDamp);

    /**
     * @return WebIDL type: float
     */
    public float getAngularDamping() {
        checkNotNull();
        return _getAngularDamping(address);
    }
    private static native float _getAngularDamping(long address);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getLinearVelocity() {
        checkNotNull();
        return PxVec3.wrapPointer(_getLinearVelocity(address));
    }
    private static native long _getLinearVelocity(long address);

    /**
     * @param linVel WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setLinearVelocity(PxVec3 linVel) {
        checkNotNull();
        _setLinearVelocity(address, linVel.getAddress());
    }
    private static native void _setLinearVelocity(long address, long linVel);

    /**
     * @param linVel   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param autowake WebIDL type: boolean
     */
    public void setLinearVelocity(PxVec3 linVel, boolean autowake) {
        checkNotNull();
        _setLinearVelocity(address, linVel.getAddress(), autowake);
    }
    private static native void _setLinearVelocity(long address, long linVel, boolean autowake);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getAngularVelocity() {
        checkNotNull();
        return PxVec3.wrapPointer(_getAngularVelocity(address));
    }
    private static native long _getAngularVelocity(long address);

    /**
     * @param angVel WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setAngularVelocity(PxVec3 angVel) {
        checkNotNull();
        _setAngularVelocity(address, angVel.getAddress());
    }
    private static native void _setAngularVelocity(long address, long angVel);

    /**
     * @param angVel   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param autowake WebIDL type: boolean
     */
    public void setAngularVelocity(PxVec3 angVel, boolean autowake) {
        checkNotNull();
        _setAngularVelocity(address, angVel.getAddress(), autowake);
    }
    private static native void _setAngularVelocity(long address, long angVel, boolean autowake);

    /**
     * @return WebIDL type: float
     */
    public float getMaxLinearVelocity() {
        checkNotNull();
        return _getMaxLinearVelocity(address);
    }
    private static native float _getMaxLinearVelocity(long address);

    /**
     * @param maxLinVel WebIDL type: float
     */
    public void setMaxLinearVelocity(float maxLinVel) {
        checkNotNull();
        _setMaxLinearVelocity(address, maxLinVel);
    }
    private static native void _setMaxLinearVelocity(long address, float maxLinVel);

    /**
     * @return WebIDL type: float
     */
    public float getMaxAngularVelocity() {
        checkNotNull();
        return _getMaxAngularVelocity(address);
    }
    private static native float _getMaxAngularVelocity(long address);

    /**
     * @param maxAngVel WebIDL type: float
     */
    public void setMaxAngularVelocity(float maxAngVel) {
        checkNotNull();
        _setMaxAngularVelocity(address, maxAngVel);
    }
    private static native void _setMaxAngularVelocity(long address, float maxAngVel);

    /**
     * @param force WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void addForce(PxVec3 force) {
        checkNotNull();
        _addForce(address, force.getAddress());
    }
    private static native void _addForce(long address, long force);

    /**
     * @param force WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode  WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void addForce(PxVec3 force, int mode) {
        checkNotNull();
        _addForce(address, force.getAddress(), mode);
    }
    private static native void _addForce(long address, long force, int mode);

    /**
     * @param force    WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode     WebIDL type: {@link PxForceModeEnum} [enum]
     * @param autowake WebIDL type: boolean
     */
    public void addForce(PxVec3 force, int mode, boolean autowake) {
        checkNotNull();
        _addForce(address, force.getAddress(), mode, autowake);
    }
    private static native void _addForce(long address, long force, int mode, boolean autowake);

    /**
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void addTorque(PxVec3 torque) {
        checkNotNull();
        _addTorque(address, torque.getAddress());
    }
    private static native void _addTorque(long address, long torque);

    /**
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode   WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void addTorque(PxVec3 torque, int mode) {
        checkNotNull();
        _addTorque(address, torque.getAddress(), mode);
    }
    private static native void _addTorque(long address, long torque, int mode);

    /**
     * @param torque   WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode     WebIDL type: {@link PxForceModeEnum} [enum]
     * @param autowake WebIDL type: boolean
     */
    public void addTorque(PxVec3 torque, int mode, boolean autowake) {
        checkNotNull();
        _addTorque(address, torque.getAddress(), mode, autowake);
    }
    private static native void _addTorque(long address, long torque, int mode, boolean autowake);

    /**
     * @param mode WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void clearForce(int mode) {
        checkNotNull();
        _clearForce(address, mode);
    }
    private static native void _clearForce(long address, int mode);

    /**
     * @param mode WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void clearTorque(int mode) {
        checkNotNull();
        _clearTorque(address, mode);
    }
    private static native void _clearTorque(long address, int mode);

    /**
     * @param force  WebIDL type: {@link PxVec3} [Const, Ref]
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     */
    public void setForceAndTorque(PxVec3 force, PxVec3 torque) {
        checkNotNull();
        _setForceAndTorque(address, force.getAddress(), torque.getAddress());
    }
    private static native void _setForceAndTorque(long address, long force, long torque);

    /**
     * @param force  WebIDL type: {@link PxVec3} [Const, Ref]
     * @param torque WebIDL type: {@link PxVec3} [Const, Ref]
     * @param mode   WebIDL type: {@link PxForceModeEnum} [enum]
     */
    public void setForceAndTorque(PxVec3 force, PxVec3 torque, int mode) {
        checkNotNull();
        _setForceAndTorque(address, force.getAddress(), torque.getAddress(), mode);
    }
    private static native void _setForceAndTorque(long address, long force, long torque, int mode);

    /**
     * @param flag  WebIDL type: {@link PxRigidBodyFlagEnum} [enum]
     * @param value WebIDL type: boolean
     */
    public void setRigidBodyFlag(int flag, boolean value) {
        checkNotNull();
        _setRigidBodyFlag(address, flag, value);
    }
    private static native void _setRigidBodyFlag(long address, int flag, boolean value);

    /**
     * @param inFlags WebIDL type: {@link PxRigidBodyFlags} [Ref]
     */
    public void setRigidBodyFlags(PxRigidBodyFlags inFlags) {
        checkNotNull();
        _setRigidBodyFlags(address, inFlags.getAddress());
    }
    private static native void _setRigidBodyFlags(long address, long inFlags);

    /**
     * @return WebIDL type: {@link PxRigidBodyFlags} [Value]
     */
    public PxRigidBodyFlags getRigidBodyFlags() {
        checkNotNull();
        return PxRigidBodyFlags.wrapPointer(_getRigidBodyFlags(address));
    }
    private static native long _getRigidBodyFlags(long address);

    /**
     * @param advanceCoefficient WebIDL type: float
     */
    public void setMinCCDAdvanceCoefficient(float advanceCoefficient) {
        checkNotNull();
        _setMinCCDAdvanceCoefficient(address, advanceCoefficient);
    }
    private static native void _setMinCCDAdvanceCoefficient(long address, float advanceCoefficient);

    /**
     * @return WebIDL type: float
     */
    public float getMinCCDAdvanceCoefficient() {
        checkNotNull();
        return _getMinCCDAdvanceCoefficient(address);
    }
    private static native float _getMinCCDAdvanceCoefficient(long address);

    /**
     * @param biasClamp WebIDL type: float
     */
    public void setMaxDepenetrationVelocity(float biasClamp) {
        checkNotNull();
        _setMaxDepenetrationVelocity(address, biasClamp);
    }
    private static native void _setMaxDepenetrationVelocity(long address, float biasClamp);

    /**
     * @return WebIDL type: float
     */
    public float getMaxDepenetrationVelocity() {
        checkNotNull();
        return _getMaxDepenetrationVelocity(address);
    }
    private static native float _getMaxDepenetrationVelocity(long address);

    /**
     * @param maxImpulse WebIDL type: float
     */
    public void setMaxContactImpulse(float maxImpulse) {
        checkNotNull();
        _setMaxContactImpulse(address, maxImpulse);
    }
    private static native void _setMaxContactImpulse(long address, float maxImpulse);

    /**
     * @return WebIDL type: float
     */
    public float getMaxContactImpulse() {
        checkNotNull();
        return _getMaxContactImpulse(address);
    }
    private static native float _getMaxContactImpulse(long address);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getInternalIslandNodeIndex() {
        checkNotNull();
        return _getInternalIslandNodeIndex(address);
    }
    private static native int _getInternalIslandNodeIndex(long address);

}
